/*
 *  linux/arch/arm/mach-pxa/colibri-evalboard.c
 *
 *  Generic Toradex Colibri Evaluation Board functions
 *  Yury Georgievskiy <yury.georgievskiy@noser.com>
 *
 *  Copyright (C) 2011 Noser Engineering
 *
 *  2011-01-25: Yury Georgievskiy <yury.georgievskiy@noser.com>
 *              initial version
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License version 2 as
 *  published by the Free Software Foundation.
 */

#include <asm/mach-types.h>

#include <linux/init.h>
#include <linux/input.h>
#include <linux/kernel.h>
#include <linux/leds.h>
#include <linux/leds_pwm.h>
#include <linux/platform_device.h>

#include <mach/colibri.h>
#include <mach/gpio.h>

#if defined(CONFIG_LEDS_GPIO) || defined(CONFIG_LEDS_GPIO_MODULE)
static struct gpio_led colibri_gpio_leds[] = {
	[0] = {
		.name			= "gpio_led1",
		.default_trigger	= "heartbeat",
		.gpio			= 0, /* dynamic init */
		.active_low		= 0,
		.retain_state_suspended	= 0,
	},
	[1] = {
		.name			= "gpio_led2",
		.default_trigger	= "none",
		.gpio			= 0, /* dynamic init */
		.active_low		= 0,
		.retain_state_suspended	= 0,
	},
};

static struct gpio_led_platform_data colibri_gpio_led_data = {
	.num_leds	= ARRAY_SIZE(colibri_gpio_leds),
	.leds		= colibri_gpio_leds,
};

static struct platform_device colibri_led_gpio_device = {
	.name		= "leds-gpio",
	.dev		= {
		.platform_data	= &colibri_gpio_led_data,
	},
};

static void __init colibri_init_leds_gpio(void)
{
/*
   Borrowed from PS2Top-Clock and PS2Bottom-Clock
   as they are not widely used nowdays:
   SODIMM pin 63, EvalBoard X11 A25
   SODIMM pin 69, EvalBoard X11 A28
*/
#define LED1_PXA270_GPIO 14
#define LED2_PXA270_GPIO 20

#define LED1_PXA300_GPIO 31
#define LED2_PXA300_GPIO 77

#define LED1_PXA310_GPIO 9
#define LED2_PXA310_GPIO 8

#define LED1_PXA320_GPIO 42
#define LED2_PXA320_GPIO 75

	if (cpu_is_pxa27x()) {
		colibri_gpio_leds[0].gpio = LED1_PXA270_GPIO;
		colibri_gpio_leds[1].gpio = LED2_PXA270_GPIO;
	} else if (cpu_is_pxa300()) {
		colibri_gpio_leds[0].gpio = LED1_PXA300_GPIO;
		colibri_gpio_leds[1].gpio = LED2_PXA300_GPIO;
	} else if (cpu_is_pxa310()) {
		colibri_gpio_leds[0].gpio = LED1_PXA310_GPIO;
		colibri_gpio_leds[1].gpio = LED2_PXA310_GPIO;
	} else if (cpu_is_pxa320()) {
		colibri_gpio_leds[0].gpio = LED1_PXA320_GPIO;
		colibri_gpio_leds[1].gpio = LED2_PXA320_GPIO;
	}
	platform_device_register(&colibri_led_gpio_device);
}
#else
static inline void colibri_init_leds_gpio(void) {}
#endif /* CONFIG_LEDS_GPIO || CONFIG_LEDS_GPIO_MODULE */

#if defined(CONFIG_LEDS_PWM) || defined(CONFIG_LEDS_PWM_MODULE)

static struct led_pwm colibri_pwm_leds[] = {
	[0] = {
		.name			= "pwm_led1",
		.default_trigger	= "heartbeat",
		.pwm_id			= 2, /* XXX_PWM2_OUT */
		.active_low		= 0,
		.max_brightness		= 255,
		.pwm_period_ns		= 50000,
	},
	[1] = {
		.name			= "pwm_led2",
		.default_trigger	= "none",
		.pwm_id			= 3, /* XXX_PWM3_OUT */
		.active_low		= 0,
		.max_brightness		= 255,
		.pwm_period_ns		= 50000,
	},
};

static struct led_pwm_platform_data colibri_led_pwm_data = {
	.num_leds	= ARRAY_SIZE(colibri_pwm_leds),
	.leds		= colibri_pwm_leds,
};

static struct platform_device colibri_leds_pwm_device = {
	.name	= "leds_pwm",
	.dev	= {
		.platform_data = &colibri_led_pwm_data,
	},
};
void __init colibri_init_pwm_gpio(void)
{
	platform_device_register(&colibri_leds_pwm_device);
}
#else
inline void colibri_init_pwm_gpio(void) {}
#endif /* CONFIG_LEDS_PWM || CONFIG_LEDS_PWM_MODULE */

void __init colibri_pxa_init_evalboard(void)
{
	colibri_init_leds_gpio();
	colibri_init_pwm_gpio();
}
